@@ -14,8 +14,9 @@ def __equals_dict(expected: dict, actual: dict) -> bool:
         if k not in actual:
             return False
         if isinstance(v, dict):
-            return __equals_dict(v, actual[k])
-        if not __equals(v, actual[k]):
+            if not __equals_dict(v, actual[k]):
+                return False
+        elif not __equals(v, actual[k]):
             return False
     return True
 
@@ -26,12 +27,12 @@ def matches(expected, actual) -> bool:
     else:
         result = __equals(expected, actual)
     if not result:
-        print(f'Expected "{expected}" does not match actual "{actual}".')
+        print(f'Expected:\n{expected}\ndoes not match actual:\n{actual}')
     return result
 
 
 def contains(expected, actual) -> bool:
     if expected in actual:
         return True
-    print(f'Expected "{expected}" was not found in actual "{actual}".')
+    print(f'Expected:\n{expected}\nwas not found in actual:\n{actual}')
     return False
